@@ -16,7 +16,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 #ifndef PCF_H
@@ -37,7 +37,7 @@ void dropout(void);
 void gram_change(int index, double newvalue);
 static void refresh_values(void);
 void PCF_computation(void);
-Nut_ToggleButton *p, *c, *f, *t, *n, *e, *z;
+Nut_ToggleButton *p, *c, *f, *t, *n, *e, *l, *i, *k, *z;
 
 private:
 MealFood *mf;
