@@ -16,7 +16,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 #include "Nut.h"
@@ -27,7 +27,9 @@
 #include "recmeal.h"
 #include <FL/Fl.H>
 #include <FL/filename.H>
+#ifndef __hpux
 #include <stdint.h>
+#endif
 #include <math.h>
 #if FL_MAJOR_VERSION == 1 && FL_MINOR_VERSION == 1
 #include <stdlib.h>
@@ -45,10 +47,10 @@ char llabel[100], flabel[100];
 static void longterm_idle_cb(void *whatever)
 {
 struct dirent **namelist;
-int n, i, s, wdate[2000], realwdate[2000], counter = 0, earliest = 1, lastdate;
+int n, i, s, wdate[2000], realwdate[2000], measurementcount = 0, earliest = 1, lastdate;
 int datapoints, unit;
 char userfile[FL_PATH_MAX], userdir[FL_PATH_MAX], buffer[100], *xdate, cdate[9];
-char unitstring[6], chartlabel[20];
+char unitstring[9], chartlabel[20];
 float weight, bf, fat[2000], lean[2000], lastlean, lastfat, biggestval = 0.0;
 float realfat[2000], realean[2000], leanavg, fatavg;
 FILE *fp;
@@ -89,19 +91,19 @@ else
      xdate = strtok(NULL," ");
      strncpy(cdate,xdate,8);
      cdate[8] = '\0';
-     wdate[counter] = reverse_time_machine(cdate);
-     if (wdate[counter] < earliest) earliest = wdate[counter];
-     fat[counter] = weight * bf / 100;
-     lean[counter] = weight - fat[counter];
-     counter++;
+     wdate[measurementcount] = reverse_time_machine(cdate);
+     if (wdate[measurementcount] < earliest) earliest = wdate[measurementcount];
+     fat[measurementcount] = weight * bf / 100;
+     lean[measurementcount] = weight - fat[measurementcount];
+     measurementcount++;
      }
-    if (counter >= 2000) break;
+    if (measurementcount >= 2000) break;
     }
    fclose(fp);
    Fl::check();
-   if (counter >= 2000) break;
+   if (measurementcount >= 2000) break;
    }
-  if (counter >= 2000) break;
+  if (measurementcount >= 2000) break;
   }
 #if FL_MAJOR_VERSION == 1 && FL_MINOR_VERSION == 1
  for (i = n; i > 0;) free((void*)(namelist[--i]));
@@ -113,7 +115,7 @@ else
 for (i = 0; i < 2000; i++) realwdate[i] = 1;
 earliest *= -1;
 datapoints = earliest + 1;
-if (datapoints < 1)
+if (measurementcount < 1)
  {
  sprintf(llabel,"No Lean Mass Measurements");
  sprintf(flabel,"No Fat Mass Measurements");
@@ -121,7 +123,7 @@ if (datapoints < 1)
  our_charts->f->label(flabel);
  return;
  }
-for (i = 0; i < counter; i++)
+for (i = 0; i < measurementcount; i++)
  {
  realwdate[wdate[i] + earliest] = wdate[i];
  realfat[wdate[i] + earliest] = fat[i];
@@ -131,7 +133,7 @@ for (i = 0; i < counter; i++)
 lastdate = realwdate[0];
 leanavg = lastlean = realean[0];
 fatavg = lastfat = realfat[0];
-for (i = 1; i < counter; i++)
+for (i = 1; i < datapoints; i++)
  {
  if (realwdate[i] == 1)
   {
@@ -144,18 +146,8 @@ for (i = 1; i < counter; i++)
  lastfat = realfat[i];
  leanavg += realean[i];
  fatavg += realfat[i];
- if (lastdate == 0) break;
- }
-while (lastdate != 0)
- {
- realwdate[i] = lastdate + 1;
- realean[i] = lastlean;
- realfat[i] = lastfat;
- leanavg += realean[i];                 
- fatavg += realfat[i];
- i++;
- lastdate++;
  }
+
 leanavg /= datapoints;
 fatavg /= datapoints;
 for (i = 0; i < datapoints; i++)
@@ -433,9 +425,13 @@ switch (nut)
    fatvo->value(0);
    adjfat->value(0);
    adjnfc->value(0);
-   balnfc->value(1);
+   balnfc->value(0);
    options.abnuts[FAT] = 0;
-   if (options.abnuts[CHO_NONFIB] == 0) balfat->label("DV 30% of Calories");
+   if (options.abnuts[CHO_NONFIB] == 0)
+    {
+    balfat->label("DV 30% of Calories");
+    options.abnuts[CHO_NONFIB] = nfcvo->value();
+    }
    i = options.screen;
    options.screen = 0;
    load_foodwork(options.defanal,options.temp_meal_root);
