@@ -16,7 +16,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 #include "util.h"
@@ -27,8 +27,8 @@
 #include <ctype.h>
 
 struct meal theusual_root, *new_theusual, meal_root, *new_meal;
-struct meal *pcfmeal[7] = { NULL,NULL,NULL,NULL,NULL,NULL,NULL };
-float pcfmatrix[7][9];
+struct meal *pcfmeal[10] = { NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL };
+float pcfmatrix[10][12];
 
 void no_op(void) {}
 
@@ -43,8 +43,11 @@ food_work.nutrient[PANTAC] += change * pcfmatrix[0][3];
 food_work.nutrient[VITE] += change * pcfmatrix[0][4];
 food_work.nutrient[CA] += change * pcfmatrix[0][5];
 food_work.nutrient[THIA] += change * pcfmatrix[0][6];
-food_work.nutrient[ENERC_KCAL] += change * pcfmatrix[0][7];
-food_work.nutrient[FAT_KCAL] += change * pcfmatrix[0][8];
+food_work.nutrient[K] += change * pcfmatrix[0][7];
+food_work.nutrient[FE] += change * pcfmatrix[0][8];
+food_work.nutrient[ZN] += change * pcfmatrix[0][9];
+food_work.nutrient[ENERC_KCAL] += change * pcfmatrix[0][10];
+food_work.nutrient[FAT_KCAL] += change * pcfmatrix[0][11];
 pcfmeal[0]->grams += 100 * change / options.mealsperday;
 }
 
@@ -59,15 +62,18 @@ food_work.nutrient[PANTAC] += change * pcfmatrix[1][3];
 food_work.nutrient[VITE] += change * pcfmatrix[1][4];
 food_work.nutrient[CA] += change * pcfmatrix[1][5];
 food_work.nutrient[THIA] += change * pcfmatrix[1][6];
-food_work.nutrient[ENERC_KCAL] += change * pcfmatrix[1][7];
-food_work.nutrient[FAT_KCAL] += change * pcfmatrix[1][8];
+food_work.nutrient[K] += change * pcfmatrix[1][7];
+food_work.nutrient[FE] += change * pcfmatrix[1][8];
+food_work.nutrient[ZN] += change * pcfmatrix[1][9];
+food_work.nutrient[ENERC_KCAL] += change * pcfmatrix[1][10];
+food_work.nutrient[FAT_KCAL] += change * pcfmatrix[1][11];
 pcfmeal[1]->grams += 100 * change / options.mealsperday;
 }
 
 void c_cal_func(void)
 {
 float change;
-change = (DV[ENERC_KCAL] - food_work.nutrient[ENERC_KCAL]) / pcfmatrix[1][7];
+change = (DV[ENERC_KCAL] - food_work.nutrient[ENERC_KCAL]) / pcfmatrix[1][10];
 food_work.nutrient[PROCNT] += change * pcfmatrix[1][0];
 food_work.nutrient[CHO_NONFIB] += change * pcfmatrix[1][1];
 food_work.nutrient[FAT] += change * pcfmatrix[1][2];
@@ -75,8 +81,11 @@ food_work.nutrient[PANTAC] += change * pcfmatrix[1][3];
 food_work.nutrient[VITE] += change * pcfmatrix[1][4];
 food_work.nutrient[CA] += change * pcfmatrix[1][5];
 food_work.nutrient[THIA] += change * pcfmatrix[1][6];
-food_work.nutrient[ENERC_KCAL] += change * pcfmatrix[1][7];
-food_work.nutrient[FAT_KCAL] += change * pcfmatrix[1][8];
+food_work.nutrient[K] += change * pcfmatrix[1][7];
+food_work.nutrient[FE] += change * pcfmatrix[1][8];
+food_work.nutrient[ZN] += change * pcfmatrix[1][9];
+food_work.nutrient[ENERC_KCAL] += change * pcfmatrix[1][10];
+food_work.nutrient[FAT_KCAL] += change * pcfmatrix[1][11];
 pcfmeal[1]->grams += 100 * change / options.mealsperday;
 }
 
@@ -91,15 +100,18 @@ food_work.nutrient[PANTAC] += change * pcfmatrix[2][3];
 food_work.nutrient[VITE] += change * pcfmatrix[2][4];
 food_work.nutrient[CA] += change * pcfmatrix[2][5];
 food_work.nutrient[THIA] += change * pcfmatrix[2][6];
-food_work.nutrient[ENERC_KCAL] += change * pcfmatrix[2][7];
-food_work.nutrient[FAT_KCAL] += change * pcfmatrix[2][8];
+food_work.nutrient[K] += change * pcfmatrix[1][7];
+food_work.nutrient[FE] += change * pcfmatrix[1][8];
+food_work.nutrient[ZN] += change * pcfmatrix[1][9];
+food_work.nutrient[ENERC_KCAL] += change * pcfmatrix[2][10];
+food_work.nutrient[FAT_KCAL] += change * pcfmatrix[2][11];
 pcfmeal[2]->grams += 100 * change / options.mealsperday;
 }
 
 void f_cal_func(void)
 {
 float change;
-change = (DV[ENERC_KCAL] - food_work.nutrient[ENERC_KCAL]) / pcfmatrix[2][7];
+change = (DV[ENERC_KCAL] - food_work.nutrient[ENERC_KCAL]) / pcfmatrix[2][10];
 food_work.nutrient[PROCNT] += change * pcfmatrix[2][0];
 food_work.nutrient[CHO_NONFIB] += change * pcfmatrix[2][1];
 food_work.nutrient[FAT] += change * pcfmatrix[2][2];
@@ -107,15 +119,18 @@ food_work.nutrient[PANTAC] += change * pcfmatrix[2][3];
 food_work.nutrient[VITE] += change * pcfmatrix[2][4];
 food_work.nutrient[CA] += change * pcfmatrix[2][5];
 food_work.nutrient[THIA] += change * pcfmatrix[2][6];
-food_work.nutrient[ENERC_KCAL] += change * pcfmatrix[2][7];
-food_work.nutrient[FAT_KCAL] += change * pcfmatrix[2][8];
+food_work.nutrient[K] += change * pcfmatrix[2][7];
+food_work.nutrient[FE] += change * pcfmatrix[2][8];
+food_work.nutrient[ZN] += change * pcfmatrix[2][9];
+food_work.nutrient[ENERC_KCAL] += change * pcfmatrix[2][10];
+food_work.nutrient[FAT_KCAL] += change * pcfmatrix[2][11];
 pcfmeal[2]->grams += 100 * change / options.mealsperday;
 }
 
 void f_cal30_func(void)
 {
 float change;
-change = (0.3 * DV[ENERC_KCAL] - food_work.nutrient[FAT_KCAL]) / pcfmatrix[2][8];
+change = (0.3 * DV[ENERC_KCAL] - food_work.nutrient[FAT_KCAL]) / pcfmatrix[2][11];
 food_work.nutrient[PROCNT] += change * pcfmatrix[2][0];
 food_work.nutrient[CHO_NONFIB] += change * pcfmatrix[2][1];
 food_work.nutrient[FAT] += change * pcfmatrix[2][2];
@@ -123,8 +138,11 @@ food_work.nutrient[PANTAC] += change * pcfmatrix[2][3];
 food_work.nutrient[VITE] += change * pcfmatrix[2][4];
 food_work.nutrient[CA] += change * pcfmatrix[2][5];
 food_work.nutrient[THIA] += change * pcfmatrix[2][6];
-food_work.nutrient[ENERC_KCAL] += change * pcfmatrix[2][7];
-food_work.nutrient[FAT_KCAL] += change * pcfmatrix[2][8];
+food_work.nutrient[K] += change * pcfmatrix[2][7];
+food_work.nutrient[FE] += change * pcfmatrix[2][8];
+food_work.nutrient[ZN] += change * pcfmatrix[2][9];
+food_work.nutrient[ENERC_KCAL] += change * pcfmatrix[2][10];
+food_work.nutrient[FAT_KCAL] += change * pcfmatrix[2][11];
 pcfmeal[2]->grams += 100 * change / options.mealsperday;
 }
 
@@ -139,8 +157,11 @@ food_work.nutrient[PANTAC] += change * pcfmatrix[3][3];
 food_work.nutrient[VITE] += change * pcfmatrix[3][4];
 food_work.nutrient[CA] += change * pcfmatrix[3][5];
 food_work.nutrient[THIA] += change * pcfmatrix[3][6];
-food_work.nutrient[ENERC_KCAL] += change * pcfmatrix[3][7];
-food_work.nutrient[FAT_KCAL] += change * pcfmatrix[3][8];
+food_work.nutrient[K] += change * pcfmatrix[3][7];
+food_work.nutrient[FE] += change * pcfmatrix[3][8];
+food_work.nutrient[ZN] += change * pcfmatrix[3][9];
+food_work.nutrient[ENERC_KCAL] += change * pcfmatrix[3][10];
+food_work.nutrient[FAT_KCAL] += change * pcfmatrix[3][11];
 pcfmeal[3]->grams += 100 * change / options.mealsperday;
 }
 
@@ -155,12 +176,15 @@ food_work.nutrient[PANTAC] += change * pcfmatrix[4][3];
 food_work.nutrient[VITE] += change * pcfmatrix[4][4];
 food_work.nutrient[CA] += change * pcfmatrix[4][5];
 food_work.nutrient[THIA] += change * pcfmatrix[4][6];
-food_work.nutrient[ENERC_KCAL] += change * pcfmatrix[4][7];
-food_work.nutrient[FAT_KCAL] += change * pcfmatrix[4][8];
+food_work.nutrient[K] += change * pcfmatrix[4][7];
+food_work.nutrient[FE] += change * pcfmatrix[4][8];
+food_work.nutrient[ZN] += change * pcfmatrix[4][9];
+food_work.nutrient[ENERC_KCAL] += change * pcfmatrix[4][10];
+food_work.nutrient[FAT_KCAL] += change * pcfmatrix[4][11];
 pcfmeal[4]->grams += 100 * change / options.mealsperday;
 }
 
-void z_func(void)
+void l_func(void)
 {
 float change;
 change = (DV[CA] - food_work.nutrient[CA]) / pcfmatrix[5][5];
@@ -171,8 +195,11 @@ food_work.nutrient[PANTAC] += change * pcfmatrix[5][3];
 food_work.nutrient[VITE] += change * pcfmatrix[5][4];
 food_work.nutrient[CA] += change * pcfmatrix[5][5];
 food_work.nutrient[THIA] += change * pcfmatrix[5][6];
-food_work.nutrient[ENERC_KCAL] += change * pcfmatrix[5][7];
-food_work.nutrient[FAT_KCAL] += change * pcfmatrix[5][8];
+food_work.nutrient[K] += change * pcfmatrix[5][7];
+food_work.nutrient[FE] += change * pcfmatrix[5][8];
+food_work.nutrient[ZN] += change * pcfmatrix[5][9];
+food_work.nutrient[ENERC_KCAL] += change * pcfmatrix[5][10];
+food_work.nutrient[FAT_KCAL] += change * pcfmatrix[5][11];
 pcfmeal[5]->grams += 100 * change / options.mealsperday;
 }
 
@@ -187,11 +214,71 @@ food_work.nutrient[PANTAC] += change * pcfmatrix[6][3];
 food_work.nutrient[VITE] += change * pcfmatrix[6][4];
 food_work.nutrient[CA] += change * pcfmatrix[6][5];
 food_work.nutrient[THIA] += change * pcfmatrix[6][6];
-food_work.nutrient[ENERC_KCAL] += change * pcfmatrix[6][7];
-food_work.nutrient[FAT_KCAL] += change * pcfmatrix[6][8];
+food_work.nutrient[K] += change * pcfmatrix[6][7];
+food_work.nutrient[FE] += change * pcfmatrix[6][8];
+food_work.nutrient[ZN] += change * pcfmatrix[6][9];
+food_work.nutrient[ENERC_KCAL] += change * pcfmatrix[6][10];
+food_work.nutrient[FAT_KCAL] += change * pcfmatrix[6][11];
 pcfmeal[6]->grams += 100 * change / options.mealsperday;
 }
 
+void k_func(void)
+{
+float change;
+change = (DV[K] - food_work.nutrient[K]) / pcfmatrix[7][7];
+food_work.nutrient[PROCNT] += change * pcfmatrix[7][0];
+food_work.nutrient[CHO_NONFIB] += change * pcfmatrix[7][1];
+food_work.nutrient[FAT] += change * pcfmatrix[7][2];
+food_work.nutrient[PANTAC] += change * pcfmatrix[7][3];
+food_work.nutrient[VITE] += change * pcfmatrix[7][4];
+food_work.nutrient[CA] += change * pcfmatrix[7][5];
+food_work.nutrient[THIA] += change * pcfmatrix[7][6];
+food_work.nutrient[K] += change * pcfmatrix[7][7];
+food_work.nutrient[FE] += change * pcfmatrix[7][8];
+food_work.nutrient[ZN] += change * pcfmatrix[7][9];
+food_work.nutrient[ENERC_KCAL] += change * pcfmatrix[7][10];
+food_work.nutrient[FAT_KCAL] += change * pcfmatrix[7][11];
+pcfmeal[7]->grams += 100 * change / options.mealsperday;
+}
+
+void i_func(void)
+{
+float change;
+change = (DV[FE] - food_work.nutrient[FE]) / pcfmatrix[8][8];
+food_work.nutrient[PROCNT] += change * pcfmatrix[8][0];
+food_work.nutrient[CHO_NONFIB] += change * pcfmatrix[8][1];
+food_work.nutrient[FAT] += change * pcfmatrix[8][2];
+food_work.nutrient[PANTAC] += change * pcfmatrix[8][3];
+food_work.nutrient[VITE] += change * pcfmatrix[8][4];
+food_work.nutrient[CA] += change * pcfmatrix[8][5];
+food_work.nutrient[THIA] += change * pcfmatrix[8][6];
+food_work.nutrient[K] += change * pcfmatrix[8][7];
+food_work.nutrient[FE] += change * pcfmatrix[8][8];
+food_work.nutrient[ZN] += change * pcfmatrix[8][9];
+food_work.nutrient[ENERC_KCAL] += change * pcfmatrix[8][10];
+food_work.nutrient[FAT_KCAL] += change * pcfmatrix[8][11];
+pcfmeal[8]->grams += 100 * change / options.mealsperday;
+}
+
+void z_func(void)
+{
+float change;
+change = (DV[ZN] - food_work.nutrient[ZN]) / pcfmatrix[9][9];
+food_work.nutrient[PROCNT] += change * pcfmatrix[9][0];
+food_work.nutrient[CHO_NONFIB] += change * pcfmatrix[9][1];
+food_work.nutrient[FAT] += change * pcfmatrix[9][2];
+food_work.nutrient[PANTAC] += change * pcfmatrix[9][3];
+food_work.nutrient[VITE] += change * pcfmatrix[9][4];
+food_work.nutrient[CA] += change * pcfmatrix[9][5];
+food_work.nutrient[THIA] += change * pcfmatrix[9][6];
+food_work.nutrient[K] += change * pcfmatrix[9][7];
+food_work.nutrient[FE] += change * pcfmatrix[9][8];
+food_work.nutrient[ZN] += change * pcfmatrix[9][9];
+food_work.nutrient[ENERC_KCAL] += change * pcfmatrix[9][10];
+food_work.nutrient[FAT_KCAL] += change * pcfmatrix[9][11];
+pcfmeal[9]->grams += 100 * change / options.mealsperday;
+}
+
 void order_new_meal()
 {
 struct meal *meal_ptr = &meal_root;
@@ -340,10 +427,13 @@ float newqty;
 if (qty != NULL && (*qty == 'P' || *qty == 'p')) nut = PROCNT;
 else if (qty != NULL && (*qty == 'C' || *qty == 'c')) nut = CHO_NONFIB;
 else if (qty != NULL && (*qty == 'F' || *qty == 'f')) nut = FAT;
+else if (qty != NULL && (*qty == 'T' || *qty == 't')) nut = THIA;
 else if (qty != NULL && (*qty == 'N' || *qty == 'n')) nut = PANTAC;
 else if (qty != NULL && (*qty == 'E' || *qty == 'e')) nut = VITE;
-else if (qty != NULL && (*qty == 'Z' || *qty == 'z')) nut = CA;
-else if (qty != NULL && (*qty == 'T' || *qty == 't')) nut = THIA;
+else if (qty != NULL && (*qty == 'L' || *qty == 'l')) nut = CA;
+else if (qty != NULL && (*qty == 'I' || *qty == 'i')) nut = FE;
+else if (qty != NULL && (*qty == 'K' || *qty == 'k')) nut = K;
+else if (qty != NULL && (*qty == 'Z' || *qty == 'z')) nut = ZN;
 if (nut != -1) while (meal_ptr->next != NULL)
  {
  if (strcmp(meal_date,meal_ptr->next->meal_date) == 0 && meal == meal_ptr->next->meal) 
@@ -456,7 +546,7 @@ pcfrun();
 void pcfrun(void)
 {
 typedef void (*xfunc)(void);
-xfunc pfunc = &no_op, cfunc = &no_op, ffunc = &no_op, nfunc = &no_op, efunc = &no_op, zfunc = &no_op, tfunc = &no_op;
+xfunc pfunc = &no_op, cfunc = &no_op, ffunc = &no_op, nfunc = &no_op, efunc = &no_op, lfunc = &no_op, tfunc = &no_op, kfunc = &no_op, ifunc = &no_op, zfunc = &no_op;
 int count = 0, iterate, savescreen;
 
 DVnotOK = 1;
@@ -471,8 +561,11 @@ if (pcfmeal[0] != NULL)
  pcfmatrix[0][4] = FoodIndex[pcfmeal[0]->food_no]->nutrient[VITE];
  pcfmatrix[0][5] = FoodIndex[pcfmeal[0]->food_no]->nutrient[CA];
  pcfmatrix[0][6] = FoodIndex[pcfmeal[0]->food_no]->nutrient[THIA];
- pcfmatrix[0][7] = FoodIndex[pcfmeal[0]->food_no]->nutrient[ENERC_KCAL];
- pcfmatrix[0][8] = FoodIndex[pcfmeal[0]->food_no]->nutrient[FAT_KCAL];
+ pcfmatrix[0][7] = FoodIndex[pcfmeal[0]->food_no]->nutrient[K];
+ pcfmatrix[0][8] = FoodIndex[pcfmeal[0]->food_no]->nutrient[FE];
+ pcfmatrix[0][9] = FoodIndex[pcfmeal[0]->food_no]->nutrient[ZN];
+ pcfmatrix[0][10] = FoodIndex[pcfmeal[0]->food_no]->nutrient[ENERC_KCAL];
+ pcfmatrix[0][11] = FoodIndex[pcfmeal[0]->food_no]->nutrient[FAT_KCAL];
  pfunc = &p_func;
  }
 if (pcfmeal[1] != NULL)
@@ -484,8 +577,11 @@ if (pcfmeal[1] != NULL)
  pcfmatrix[1][4] = FoodIndex[pcfmeal[1]->food_no]->nutrient[VITE];
  pcfmatrix[1][5] = FoodIndex[pcfmeal[1]->food_no]->nutrient[CA];
  pcfmatrix[1][6] = FoodIndex[pcfmeal[1]->food_no]->nutrient[THIA];
- pcfmatrix[1][7] = FoodIndex[pcfmeal[1]->food_no]->nutrient[ENERC_KCAL];
- pcfmatrix[1][8] = FoodIndex[pcfmeal[1]->food_no]->nutrient[FAT_KCAL];
+ pcfmatrix[1][7] = FoodIndex[pcfmeal[1]->food_no]->nutrient[K];
+ pcfmatrix[1][8] = FoodIndex[pcfmeal[1]->food_no]->nutrient[FE];
+ pcfmatrix[1][9] = FoodIndex[pcfmeal[1]->food_no]->nutrient[ZN];
+ pcfmatrix[1][10] = FoodIndex[pcfmeal[1]->food_no]->nutrient[ENERC_KCAL];
+ pcfmatrix[1][11] = FoodIndex[pcfmeal[1]->food_no]->nutrient[FAT_KCAL];
  if (options.abnuts[ENERC_KCAL] >= 0 && options.abnuts[CHO_NONFIB] == 0) cfunc = &c_cal_func; 
  else cfunc = &c_func;
  }
@@ -498,8 +594,11 @@ if (pcfmeal[2] != NULL)
  pcfmatrix[2][4] = FoodIndex[pcfmeal[2]->food_no]->nutrient[VITE];
  pcfmatrix[2][5] = FoodIndex[pcfmeal[2]->food_no]->nutrient[CA];
  pcfmatrix[2][6] = FoodIndex[pcfmeal[2]->food_no]->nutrient[THIA];
- pcfmatrix[2][7] = FoodIndex[pcfmeal[2]->food_no]->nutrient[ENERC_KCAL];
- pcfmatrix[2][8] = FoodIndex[pcfmeal[2]->food_no]->nutrient[FAT_KCAL];
+ pcfmatrix[2][7] = FoodIndex[pcfmeal[2]->food_no]->nutrient[K];
+ pcfmatrix[2][7] = FoodIndex[pcfmeal[2]->food_no]->nutrient[FE];
+ pcfmatrix[2][8] = FoodIndex[pcfmeal[2]->food_no]->nutrient[ZN];
+ pcfmatrix[2][10] = FoodIndex[pcfmeal[2]->food_no]->nutrient[ENERC_KCAL];
+ pcfmatrix[2][11] = FoodIndex[pcfmeal[2]->food_no]->nutrient[FAT_KCAL];
  if (options.abnuts[ENERC_KCAL] >= 0 && options.abnuts[FAT] == 0 && options.abnuts[CHO_NONFIB] != 0) ffunc = &f_cal_func; 
  else if (options.abnuts[ENERC_KCAL] >= 0 && options.abnuts[FAT] == 0 && options.abnuts[CHO_NONFIB] == 0) ffunc = &f_cal30_func; 
  else ffunc = &f_func;
@@ -513,8 +612,11 @@ if (pcfmeal[3] != NULL)
  pcfmatrix[3][4] = FoodIndex[pcfmeal[3]->food_no]->nutrient[VITE];
  pcfmatrix[3][5] = FoodIndex[pcfmeal[3]->food_no]->nutrient[CA];
  pcfmatrix[3][6] = FoodIndex[pcfmeal[3]->food_no]->nutrient[THIA];
- pcfmatrix[3][7] = FoodIndex[pcfmeal[3]->food_no]->nutrient[ENERC_KCAL];
- pcfmatrix[3][8] = FoodIndex[pcfmeal[3]->food_no]->nutrient[FAT_KCAL];
+ pcfmatrix[3][7] = FoodIndex[pcfmeal[3]->food_no]->nutrient[K];
+ pcfmatrix[3][8] = FoodIndex[pcfmeal[3]->food_no]->nutrient[FE];
+ pcfmatrix[3][9] = FoodIndex[pcfmeal[3]->food_no]->nutrient[ZN];
+ pcfmatrix[3][10] = FoodIndex[pcfmeal[3]->food_no]->nutrient[ENERC_KCAL];
+ pcfmatrix[3][11] = FoodIndex[pcfmeal[3]->food_no]->nutrient[FAT_KCAL];
  nfunc = &n_func;                                              
  }
 if (pcfmeal[4] != NULL)
@@ -526,8 +628,11 @@ if (pcfmeal[4] != NULL)
  pcfmatrix[4][4] = FoodIndex[pcfmeal[4]->food_no]->nutrient[VITE];
  pcfmatrix[4][5] = FoodIndex[pcfmeal[4]->food_no]->nutrient[CA];
  pcfmatrix[4][6] = FoodIndex[pcfmeal[4]->food_no]->nutrient[THIA];
- pcfmatrix[4][7] = FoodIndex[pcfmeal[4]->food_no]->nutrient[ENERC_KCAL];
- pcfmatrix[4][8] = FoodIndex[pcfmeal[4]->food_no]->nutrient[FAT_KCAL];
+ pcfmatrix[4][7] = FoodIndex[pcfmeal[4]->food_no]->nutrient[K];
+ pcfmatrix[4][8] = FoodIndex[pcfmeal[4]->food_no]->nutrient[FE];
+ pcfmatrix[4][9] = FoodIndex[pcfmeal[4]->food_no]->nutrient[ZN];
+ pcfmatrix[4][10] = FoodIndex[pcfmeal[4]->food_no]->nutrient[ENERC_KCAL];
+ pcfmatrix[4][11] = FoodIndex[pcfmeal[4]->food_no]->nutrient[FAT_KCAL];
  efunc = &e_func;
  }
 if (pcfmeal[5] != NULL)
@@ -539,9 +644,12 @@ if (pcfmeal[5] != NULL)
  pcfmatrix[5][4] = FoodIndex[pcfmeal[5]->food_no]->nutrient[VITE];
  pcfmatrix[5][5] = FoodIndex[pcfmeal[5]->food_no]->nutrient[CA];
  pcfmatrix[5][6] = FoodIndex[pcfmeal[5]->food_no]->nutrient[THIA];
- pcfmatrix[5][7] = FoodIndex[pcfmeal[5]->food_no]->nutrient[ENERC_KCAL];
- pcfmatrix[5][8] = FoodIndex[pcfmeal[5]->food_no]->nutrient[FAT_KCAL];
- zfunc = &z_func;
+ pcfmatrix[5][7] = FoodIndex[pcfmeal[5]->food_no]->nutrient[K];
+ pcfmatrix[5][8] = FoodIndex[pcfmeal[5]->food_no]->nutrient[FE];
+ pcfmatrix[5][9] = FoodIndex[pcfmeal[5]->food_no]->nutrient[ZN];
+ pcfmatrix[5][10] = FoodIndex[pcfmeal[5]->food_no]->nutrient[ENERC_KCAL];
+ pcfmatrix[5][11] = FoodIndex[pcfmeal[5]->food_no]->nutrient[FAT_KCAL];
+ lfunc = &l_func;
  }
 if (pcfmeal[6] != NULL)
  {
@@ -552,10 +660,61 @@ if (pcfmeal[6] != NULL)
  pcfmatrix[6][4] = FoodIndex[pcfmeal[6]->food_no]->nutrient[VITE];
  pcfmatrix[6][5] = FoodIndex[pcfmeal[6]->food_no]->nutrient[CA];
  pcfmatrix[6][6] = FoodIndex[pcfmeal[6]->food_no]->nutrient[THIA];
- pcfmatrix[6][7] = FoodIndex[pcfmeal[6]->food_no]->nutrient[ENERC_KCAL];
- pcfmatrix[6][8] = FoodIndex[pcfmeal[6]->food_no]->nutrient[FAT_KCAL];
+ pcfmatrix[6][7] = FoodIndex[pcfmeal[6]->food_no]->nutrient[K];
+ pcfmatrix[6][8] = FoodIndex[pcfmeal[6]->food_no]->nutrient[FE];
+ pcfmatrix[6][9] = FoodIndex[pcfmeal[6]->food_no]->nutrient[ZN];
+ pcfmatrix[6][10] = FoodIndex[pcfmeal[6]->food_no]->nutrient[ENERC_KCAL];
+ pcfmatrix[6][11] = FoodIndex[pcfmeal[6]->food_no]->nutrient[FAT_KCAL];
  tfunc = &t_func;
  }
+if (pcfmeal[7] != NULL)
+ {
+ pcfmatrix[7][0] = FoodIndex[pcfmeal[7]->food_no]->nutrient[PROCNT];
+ pcfmatrix[7][1] = FoodIndex[pcfmeal[7]->food_no]->nutrient[CHO_NONFIB];
+ pcfmatrix[7][2] = FoodIndex[pcfmeal[7]->food_no]->nutrient[FAT];
+ pcfmatrix[7][3] = FoodIndex[pcfmeal[7]->food_no]->nutrient[PANTAC];
+ pcfmatrix[7][4] = FoodIndex[pcfmeal[7]->food_no]->nutrient[VITE];
+ pcfmatrix[7][5] = FoodIndex[pcfmeal[7]->food_no]->nutrient[CA];
+ pcfmatrix[7][6] = FoodIndex[pcfmeal[7]->food_no]->nutrient[THIA];
+ pcfmatrix[7][7] = FoodIndex[pcfmeal[7]->food_no]->nutrient[K];
+ pcfmatrix[7][8] = FoodIndex[pcfmeal[7]->food_no]->nutrient[FE];
+ pcfmatrix[7][9] = FoodIndex[pcfmeal[7]->food_no]->nutrient[ZN];
+ pcfmatrix[7][10] = FoodIndex[pcfmeal[7]->food_no]->nutrient[ENERC_KCAL];
+ pcfmatrix[7][11] = FoodIndex[pcfmeal[7]->food_no]->nutrient[FAT_KCAL];
+ kfunc = &k_func;
+ }
+if (pcfmeal[8] != NULL)
+ {
+ pcfmatrix[8][0] = FoodIndex[pcfmeal[8]->food_no]->nutrient[PROCNT];
+ pcfmatrix[8][1] = FoodIndex[pcfmeal[8]->food_no]->nutrient[CHO_NONFIB];
+ pcfmatrix[8][2] = FoodIndex[pcfmeal[8]->food_no]->nutrient[FAT];
+ pcfmatrix[8][3] = FoodIndex[pcfmeal[8]->food_no]->nutrient[PANTAC];
+ pcfmatrix[8][4] = FoodIndex[pcfmeal[8]->food_no]->nutrient[VITE];
+ pcfmatrix[8][5] = FoodIndex[pcfmeal[8]->food_no]->nutrient[CA];
+ pcfmatrix[8][6] = FoodIndex[pcfmeal[8]->food_no]->nutrient[THIA];
+ pcfmatrix[8][7] = FoodIndex[pcfmeal[8]->food_no]->nutrient[K];
+ pcfmatrix[8][8] = FoodIndex[pcfmeal[8]->food_no]->nutrient[FE];
+ pcfmatrix[8][9] = FoodIndex[pcfmeal[8]->food_no]->nutrient[ZN];
+ pcfmatrix[8][10] = FoodIndex[pcfmeal[8]->food_no]->nutrient[ENERC_KCAL];
+ pcfmatrix[8][11] = FoodIndex[pcfmeal[8]->food_no]->nutrient[FAT_KCAL];
+ ifunc = &i_func;
+ }
+if (pcfmeal[9] != NULL)
+ {
+ pcfmatrix[9][0] = FoodIndex[pcfmeal[9]->food_no]->nutrient[PROCNT];
+ pcfmatrix[9][1] = FoodIndex[pcfmeal[9]->food_no]->nutrient[CHO_NONFIB];
+ pcfmatrix[9][2] = FoodIndex[pcfmeal[9]->food_no]->nutrient[FAT];
+ pcfmatrix[9][3] = FoodIndex[pcfmeal[9]->food_no]->nutrient[PANTAC];
+ pcfmatrix[9][4] = FoodIndex[pcfmeal[9]->food_no]->nutrient[VITE];
+ pcfmatrix[9][5] = FoodIndex[pcfmeal[9]->food_no]->nutrient[CA];
+ pcfmatrix[9][6] = FoodIndex[pcfmeal[9]->food_no]->nutrient[THIA];
+ pcfmatrix[9][7] = FoodIndex[pcfmeal[9]->food_no]->nutrient[K];
+ pcfmatrix[9][8] = FoodIndex[pcfmeal[9]->food_no]->nutrient[FE];
+ pcfmatrix[9][9] = FoodIndex[pcfmeal[9]->food_no]->nutrient[ZN];
+ pcfmatrix[9][10] = FoodIndex[pcfmeal[9]->food_no]->nutrient[ENERC_KCAL];
+ pcfmatrix[9][11] = FoodIndex[pcfmeal[9]->food_no]->nutrient[FAT_KCAL];
+ zfunc = &z_func;
+ }
 
 savescreen = options.screen;
 options.screen = 0;
@@ -572,12 +731,15 @@ for (iterate = 0; iterate < 3; iterate++)
   ffunc();
   nfunc();
   efunc();
-  zfunc();
+  lfunc();
   tfunc();
+  kfunc();
+  ifunc();
+  zfunc();
   }
  }
 
-for (count = 0; count < 5; count++) if (pcfmeal[count] != NULL)
+for (count = 0; count < 10; count++) if (pcfmeal[count] != NULL)
  {
  if (pcfmeal[count]->grams != pcfmeal[count]->grams) pcfmeal[count]->grams = 0;
  if (pcfmeal[count]->grams < -1000) pcfmeal[count]->grams = 0;
@@ -592,7 +754,7 @@ void pcftweak(int nut, struct meal *ptr)
 {
 int i;
 
-for (i = 0; i < 7; i++) if (ptr == pcfmeal[i])
+for (i = 0; i < 10; i++) if (ptr == pcfmeal[i])
  {
  FoodIndex[pcfmeal[i]->food_no]->pcf = ' ';
  pcfmeal[i] = NULL;
@@ -643,7 +805,7 @@ switch (nut)
   if (pcfmeal[5] != NULL) FoodIndex[pcfmeal[5]->food_no]->pcf = ' ';
   else if (i == 5) break;
   pcfmeal[5] = ptr;
-  FoodIndex[pcfmeal[5]->food_no]->pcf = 'z';
+  FoodIndex[pcfmeal[5]->food_no]->pcf = 'l';
   break;
  case THIA :
   if (pcfmeal[6] != NULL) FoodIndex[pcfmeal[6]->food_no]->pcf = ' ';
@@ -651,6 +813,24 @@ switch (nut)
   pcfmeal[6] = ptr;
   FoodIndex[pcfmeal[6]->food_no]->pcf = 't';
   break;
+ case K :
+  if (pcfmeal[7] != NULL) FoodIndex[pcfmeal[7]->food_no]->pcf = ' ';
+  else if (i == 7) break;
+  pcfmeal[7] = ptr;
+  FoodIndex[pcfmeal[7]->food_no]->pcf = 'k';
+  break;
+ case FE :
+  if (pcfmeal[8] != NULL) FoodIndex[pcfmeal[8]->food_no]->pcf = ' ';
+  else if (i == 8) break;
+  pcfmeal[8] = ptr;
+  FoodIndex[pcfmeal[8]->food_no]->pcf = 'i';
+  break;
+ case ZN :
+  if (pcfmeal[9] != NULL) FoodIndex[pcfmeal[9]->food_no]->pcf = ' ';
+  else if (i == 9) break;
+  pcfmeal[9] = ptr;
+  FoodIndex[pcfmeal[9]->food_no]->pcf = 'z';
+  break;
  default : break;
  }
 }
@@ -696,8 +876,23 @@ if (ptr == NULL)
   FoodIndex[pcfmeal[6]->food_no]->pcf = ' ';
   pcfmeal[6] = NULL;
   }
+ if (pcfmeal[7] != NULL)
+  {
+  FoodIndex[pcfmeal[7]->food_no]->pcf = ' ';
+  pcfmeal[7] = NULL;
+  }
+ if (pcfmeal[8] != NULL)
+  {
+  FoodIndex[pcfmeal[8]->food_no]->pcf = ' ';
+  pcfmeal[8] = NULL;
+  }
+ if (pcfmeal[9] != NULL)
+  {
+  FoodIndex[pcfmeal[9]->food_no]->pcf = ' ';
+  pcfmeal[9] = NULL;
+  }
  }
-else for (i = 0; i < 7; i++) if (pcfmeal[i] == ptr)
+else for (i = 0; i < 10; i++) if (pcfmeal[i] == ptr)
  {
  FoodIndex[pcfmeal[i]->food_no]->pcf = ' ';
  pcfmeal[i] = NULL;
