@@ -76,6 +76,7 @@ while (fgets(line,300,stdin) != NULL)
               if (strncmp(nam,"Dessert",7) == 0) target      =  0.15;
               if (strncmp(nam,"Dessert",7) == 0 && strstr(nam,"powdered") != NULL) target      =  0.05;
               if (strncmp(nam,"Dessert",7) == 0 && strstr(nam,"prepared") != NULL) target      =  0.15;
+              if (strncmp(nam,"Dulce de Leche",14) == 0) target      =  3;
               if (strncmp(nam,"Milk",4) == 0 && strstr(nam,"dry") != NULL) target      =  1;
               if (strncmp(nam,"Milk",4) == 0 && strstr(nam,"canned") != NULL) target      =  1;
               if (strncmp(nam,"Milk, buttermilk, dried",23) == 0) target = .25;
@@ -86,10 +87,12 @@ while (fgets(line,300,stdin) != NULL)
               if (strncmp(nam,"Egg, white, dried",17) == 0) target      = .5;
               if (strncmp(nam,"Egg, goose",10) == 0) target      = 5;
               if (strncmp(nam,"Egg, quail",10) == 0) target      = .33;
+              if (strncmp(nam,"Egg Mix",7) == 0) target      = 1;
               if (strncmp(nam,"Egg substitute",14) == 0) target      = 1.75;
               if (strncmp(nam,"Egg substitute, powder",22) == 0) target      = .33;
               if (strncmp(nam,"Cheese, parmesan, shredded",26) == 0) target      = .16;
               if (strncmp(nam,"Cheese fondue",13) == 0) target = 2;
+              if (strncmp(nam,"Protein supplement",18) == 0) target = 1.5;
               if (strncmp(nam,"KRAFT",5) == 0) target = 1;
               if (strncmp(nam,"KRAFT BREYERS",13) == 0) target = 8;
               if (strncmp(nam,"Whipped topping",15) == 0) target = .5;
@@ -186,6 +189,7 @@ while (fgets(line,300,stdin) != NULL)
               if (strncmp(nam,"Lemon juice",11) == 0) target = 1;
               if (strncmp(nam,"Pummelo",7) == 0) target = 7;
               if (strncmp(nam,"Guava sauce",11) == 0) target = 2;
+              if (strncmp(nam,"Strawberries, raw",17) == 0) target = 5;
               break;
   case 1000 : target = 3;
               if (strstr(nam,"leaf fat") != NULL) target = 1;
