@@ -16,7 +16,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 #include "anameal.h"
@@ -105,14 +105,20 @@ for ( ; ; )
     else if (strchr(tokenx,'C') != NULL) modify_meal(meal_date,meal,modfood,"c");
     else if (strchr(tokenx,'f') != NULL) modify_meal(meal_date,meal,modfood,"f");
     else if (strchr(tokenx,'F') != NULL) modify_meal(meal_date,meal,modfood,"f");
+    else if (strchr(tokenx,'t') != NULL) modify_meal(meal_date,meal,modfood,"t");
+    else if (strchr(tokenx,'T') != NULL) modify_meal(meal_date,meal,modfood,"t");
     else if (strchr(tokenx,'n') != NULL) modify_meal(meal_date,meal,modfood,"n");
     else if (strchr(tokenx,'N') != NULL) modify_meal(meal_date,meal,modfood,"n");
     else if (strchr(tokenx,'e') != NULL) modify_meal(meal_date,meal,modfood,"e");
     else if (strchr(tokenx,'E') != NULL) modify_meal(meal_date,meal,modfood,"e");
+    else if (strchr(tokenx,'l') != NULL) modify_meal(meal_date,meal,modfood,"l");
+    else if (strchr(tokenx,'L') != NULL) modify_meal(meal_date,meal,modfood,"l");
+    else if (strchr(tokenx,'i') != NULL) modify_meal(meal_date,meal,modfood,"i");
+    else if (strchr(tokenx,'I') != NULL) modify_meal(meal_date,meal,modfood,"i");
+    else if (strchr(tokenx,'k') != NULL) modify_meal(meal_date,meal,modfood,"k");
+    else if (strchr(tokenx,'K') != NULL) modify_meal(meal_date,meal,modfood,"k");
     else if (strchr(tokenx,'z') != NULL) modify_meal(meal_date,meal,modfood,"z");
     else if (strchr(tokenx,'Z') != NULL) modify_meal(meal_date,meal,modfood,"z");
-    else if (strchr(tokenx,'t') != NULL) modify_meal(meal_date,meal,modfood,"t");
-    else if (strchr(tokenx,'T') != NULL) modify_meal(meal_date,meal,modfood,"t");
     else modify_meal(meal_date,meal,modfood,token);
     }
    else modify_meal(meal_date,meal,modfood,token);
